@@ -9,13 +9,13 @@
    GNU MP RELEASE.
 
 
-Copyright (C) 1992, 1994, 1996, 2000 Free Software Foundation, Inc.
+Copyright 1992, 1994, 1996, 2000 Free Software Foundation, Inc.
 
 This file is part of the GNU MP Library.
 
 The GNU MP Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MP Library is distributed in the hope that it will be useful, but
@@ -24,9 +24,7 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MP Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-MA 02111-1307, USA. */
+along with the GNU MP Library.  If not, see http://www.gnu.org/licenses/.  */
 
 #include "gmp.h"
 #include "gmp-impl.h"
@@ -39,6 +37,9 @@ mpn_udiv_w_sdiv (rp, a1, a0, d)
   mp_limb_t q, r;
   mp_limb_t c0, c1, b1;
 
+  ASSERT (d != 0);
+  ASSERT (a1 < d);
+
   if ((mp_limb_signed_t) d >= 0)
     {
       if (a1 < d - a1 - (a0 >> (BITS_PER_MP_LIMB - 1)))
